Index: applications/editors/josm/plugins/videomapping/.classpath
===================================================================
--- applications/editors/josm/plugins/videomapping/.classpath	(revision 25220)
+++ applications/editors/josm/plugins/videomapping/.classpath	(revision 25250)
@@ -7,5 +7,5 @@
 	<classpathentry kind="lib" path="lib/jna.jar"/>
 	<classpathentry kind="lib" path="lib/log4j.jar"/>
-	<classpathentry kind="lib" path="lib/vlcj-1.1.2.jar"/>
+	<classpathentry kind="lib" path="lib/vlcj-1.1.5.1.jar"/>
 	<classpathentry combineaccessrules="false" kind="src" path="/core"/>
 	<classpathentry kind="output" path="bin"/>
Index: applications/editors/josm/plugins/videomapping/build.xml
===================================================================
--- applications/editors/josm/plugins/videomapping/build.xml	(revision 25220)
+++ applications/editors/josm/plugins/videomapping/build.xml	(revision 25250)
@@ -47,5 +47,5 @@
 	<property name="ant.build.javac.target" value="1.5"/>
 	<property name="plugin.jar"             value="${plugin.dist.dir}/${ant.project.name}.jar"/>
-	<property name="vlcj"                  value="lib/vlcj-1.1.2.jar"/>
+	<property name="vlcj"                  value="lib/vlcj-1.1.5.1.jar"/>
 	<property name="jna"                  value="lib/jna.jar"/>
 	<property name="log4j"                  value="lib/log4j.jar"/>
Index: applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/GpsPlayer.java
===================================================================
--- applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/GpsPlayer.java	(revision 25220)
+++ applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/GpsPlayer.java	(revision 25250)
@@ -113,12 +113,20 @@
         Main.map.mapView.repaint(); //seperate modell and view logic...
     }
-    //go to the position at the timecode e.g.g "14:00:01";
+    //go to the position e.g.  "14.4.2010 14:00:01";
     public void jump(Date GPSAbsTime)
     {
-    	Date zero=start.getTime();
+    	Date zero=start.getTime();//TODO better Time wayfinding
     	Date starttime = new Date(zero.getHours(),zero.getMinutes(),zero.getSeconds());
     	long diff=GPSAbsTime.getTime()-starttime.getTime();
-        goTo(getWaypoint(diff)); //TODO replace Time by Date?
-    }
+        goTo(getWaypoint(diff)); 
+    }
+    
+    //jumps to a specific time since the beginning
+    public void jump(long relTime) {
+        int pos = Math.round(relTime/1000);//TODO assumes the time is constant
+        goTo(pos);
+        if (autoCenter) Main.map.mapView.zoomTo(curr.getCoor());
+    }
+    
  
     //gets only points on the line of the GPS track (between waypoints) nearby the point m
@@ -322,11 +330,5 @@
     
     
-    //jumps to a specific time
-    public void jump(long relTime) {
-        int pos = Math.round(relTime/1000);//TODO assumes the time is constant
-        goTo(pos);
-        if (autoCenter) Main.map.mapView.zoomTo(curr.getCoor());
-    }
-    
+
     //toggles walking along the track
     /* public void play(){
Index: applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/PositionLayer.java
===================================================================
--- applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/PositionLayer.java	(revision 25220)
+++ applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/PositionLayer.java	(revision 25250)
@@ -4,4 +4,5 @@
 import java.text.SimpleDateFormat;
 import java.util.Collections;
+import java.util.Date;
 import java.util.LinkedList;
 import java.util.List;
@@ -260,6 +261,6 @@
                     //jump if we know position
                     if(wp.attr.containsKey("synced"))
-                    {                       
-                        if(gpsVP!=null) gpsVP.jumpToGPSTime(gps.getRelativeTime()); //call videoplayers to set right position
+                    {
+                        if(gpsVP!=null) gpsVP.jumpToGPSTime(new Date(gps.getRelativeTime())); //call videoplayers to set right position
                     }
                 }
Index: applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/VideoMappingPlugin.java
===================================================================
--- applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/VideoMappingPlugin.java	(revision 25220)
+++ applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/VideoMappingPlugin.java	(revision 25250)
@@ -203,5 +203,5 @@
 	                if (t!=null)
 	                {
-	                    player.jumpToGPSTime(t.getTime());
+	                    player.jumpToGPSTime(t);
 	                }                       
             	}
Index: applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/video/SimpleVideoPlayer.java
===================================================================
--- applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/video/SimpleVideoPlayer.java	(revision 25220)
+++ applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/video/SimpleVideoPlayer.java	(revision 25250)
@@ -503,4 +503,44 @@
         }
 
+		public void backward(MediaPlayer arg0) {
+			// TODO Auto-generated method stub
+			
+		}
+
+		public void buffering(MediaPlayer arg0) {
+			// TODO Auto-generated method stub
+			
+		}
+
+		public void forward(MediaPlayer arg0) {
+			// TODO Auto-generated method stub
+			
+		}
+
+		public void opening(MediaPlayer arg0) {
+			// TODO Auto-generated method stub
+			
+		}
+
+		public void pausableChanged(MediaPlayer arg0, int arg1) {
+			// TODO Auto-generated method stub
+			
+		}
+
+		public void seekableChanged(MediaPlayer arg0, int arg1) {
+			// TODO Auto-generated method stub
+			
+		}
+
+		public void snapshotTaken(MediaPlayer arg0, String arg1) {
+			// TODO Auto-generated method stub
+			
+		}
+
+		public void titleChanged(MediaPlayer arg0, int arg1) {
+			// TODO Auto-generated method stub
+			
+		}
+
     
 

Index: applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/video/GPSVideoPlayer.java
===================================================================
--- applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/video/GPSVideoPlayer.java	(revision 25220)
+++ applications/editors/josm/plugins/videomapping/src/org/openstreetmap/josm/plugins/videomapping/video/GPSVideoPlayer.java	(revision 25250)
@@ -130,4 +130,5 @@
     }
     
+    /*
     public void play(long gpsstart)
     {
@@ -137,4 +138,5 @@
         //gps.play();
     }
+    */
     
     public void play()
@@ -149,14 +151,14 @@
     
    
-    //jumps in video to the corresponding Video time (external triggered)
-    public void jumpToGPSTime(long gpsT)
+    //jumps in video to the corresponding GPS time(xx:yy:zz) not date (external triggered)
+    public void jumpToGPSTime(java.util.Date date)
     {
         if(!synced)
         {
             //when not synced we can just move the icon to the right position           
-            gps.jump(new Time(gpsT));
+            gps.jump(date);
             Main.map.mapView.repaint();
         }
-        video.jump(getVideoTime(gpsT));
+        video.jump(getVideoTime(date.getTime()));
     }
     